# How to Contribute

We welcome contributions of new Processors that can be shared with the
community. Please add your new Processors under the [`contrib/`](contrib)
folder.

## Contributor License Agreement

Contributions to this project must be accompanied by a Contributor License
Agreement. You (or your employer) retain the copyright to your contribution,
this simply gives us permission to use and redistribute your contributions as
part of the project.

Visit <https://cla.developers.google.com/> to see your current agreements on
file or to sign a new one.

You generally only need to submit a CLA once. If you've already submitted one
(even for a different Google project), you likely don't need to do it again.

## Code reviews

All submissions, including those from project members, require code review. We
use GitHub pull requests for this process.

For more information on using pull requests, please consult
[GitHub Help](https://help.github.com/articles/about-pull-requests/).

## Community Guidelines

This project adheres to
[Google's Open Source Community Guidelines](https://opensource.google/conduct/).